@@ -13,6 +13,7 @@
 #    under the License.
 
 import os
+import subprocess
 import sys
 
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
@@ -32,7 +33,7 @@ sys.path.insert(0, os.path.abspath('./'))
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.todo',
-              'sphinx.ext.coverage', 'sphinx.ext.pngmath',
+              'sphinx.ext.coverage',
               'sphinx.ext.viewcode', 'sphinxcontrib.httpdomain']
 
 if not on_rtd:
@@ -82,12 +83,13 @@ if not on_rtd:
     #TODO(efedorova): Change local theme to corresponds with the theme on rtd
     pass
 
-
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
 #html_last_updated_fmt = '%b %d, %Y'
-git_cmd = "git log --pretty=format:'%ad, commit %h' --date=local -n1"
-html_last_updated_fmt = os.popen(git_cmd).read()
+git_cmd = ["git", "log", "--pretty=format:'%ad, commit %h'", "--date=local",
+           "-n1"]
+html_last_updated_fmt = subprocess.Popen(
+    git_cmd, stdout=subprocess.PIPE).communicate()[0]
 
 
 # The name for this set of Sphinx documents. If None, it defaults to
